extensions [gis]

__includes [ "parameters_rev.nls" "initialise_rev.nls" "resets_rev.nls"]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; MAIN PROCEDURES
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  ;run for 40 years, 1 tick = 3 months
  if (ticks > 160) [stop]

  ;create new community instigators to replace previously removed due to failure
  let num-new-communities (initial-communities - (count instigators with [instigator-type = "community"]))
  simple-create-instigators num-new-communities "community" green community-max-developments community-max-operational

  ;implement idea stage
  develop-idea

  ;implement feasibility stage
  ask projects with [busy = 0 and built = False and feasibility = False] [do-feasibility-study]

  ;implement procure and build stage
  ask projects with [feasibility = True and busy = 0 and built = False] [procure-and-build]

  ;decrement busy variable for each project
  ask projects with [busy > 0] [
    set busy (busy - 1)
  ]
  tick
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; PHASE 1: IDEA
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;First of the three stages: develop the idea and create project agent with location and size
to develop-idea
  ;instigators get the idea and hatch a project with location
  ask instigators with [((count projects with [(owner = myself) and (built = False)]) < max-developments)                        ; check development capacity
                        and ((count projects with [(owner = myself) and (built = True)]) < max-operational)] [get-DH-idea]       ; and operational capacity

  ;choose size of project
  ask projects with [initialised = FALSE] [set-project-size]
end

;Create project agent based on probabilistic success
to get-DH-idea
  ;let idea-rate 0

  ;count number of built projects
  let built-projects (count projects with [(built = True)])
  let my-built-projects (count projects with ([(owner = myself) and (built = True)]))

  ;calculate appropriate idea rate, representing the likelihood of internal agreement to proceed.
  if (instigator-type = "LA") [
    ; first calculate the idea rate including learning from previous success, and pot-ideas for calculating success rates
    set idea-rate (Experience2 my-built-projects built-projects (idea-rate-LA / 6.0) idea-rate-LA)

    ; then calculate the max-developments including learning
    set max-developments (Experience2 my-built-projects built-projects (LA-max-developments / 6.0) LA-max-developments)
  ]
  if (instigator-type = "commercial") [
    set idea-rate (Experience2 my-built-projects built-projects (idea-rate-commercial / 6.0) idea-rate-commercial)

    set max-developments (Experience2 my-built-projects built-projects (commercial-max-developments / 6.0) commercial-max-developments)
  ]
  if (instigator-type = "community") [
    set idea-rate ((Experience1 built-projects (idea-rate-community / 6.0) idea-rate-community) / 6.0)
  ]

  ;idea based on random decision
  let decision random-float 1
  ifelse ( decision < idea-rate )
    [
      let number (max-developments - (count projects with [(owner = myself) and (built = False)]))            ;number of projects to attempt

      set project-counter (project-counter + number)

      ; create the required number of new projects
      hatch-projects number [
        set idea-counter (idea-counter + 1)
        set owner myself
        set project-type ([instigator-type] of myself)
        set initialised FALSE
        set economic-social-feasibility FALSE
        set economic-comm-feasibility FALSE
        set social-feasibility FALSE
        set feasibility FALSE
        set built FALSE
        set eco-project False
        set poverty-project False
        set shape "star"
        if (project-type = "LA") [
          set-LA-project-location              ;LA location choice
          set LA-idea-counter (LA-idea-counter + 1)
          set color magenta
        ]
        if (project-type = "commercial") [
          set-commercial-project-location       ;commercial location choice
          set commercial-idea-counter (commercial-idea-counter + 1)
          set color blue
        ]
        if (project-type = "community") [
          set community-idea-counter (community-idea-counter + 1)
          set color green
        ]
      ]
    ]
    [
      if (instigator-type = "community") [ ; kill off unsuccessful community organisations
        die
      ]
    ]
end

;Set the location of an LA instigated project
to set-LA-project-location
  move-to (one-of patches with [ (social-house-density > LA-social-threshold) or (private-house-density > LA-private-threshold) ])
end

;Set the location of commercially instigated project
to set-commercial-project-location
  move-to (one-of patches with [ (private-house-density > comm-private-threshold) ])
end

;Determine the planned size of the project, using units of total heat supplied (number of addresses * demand per address)
to set-project-size
  ; communities never access large demands:
  ifelse (project-type = "community") [
    set planned-size (random-normal community-size-mean community-size-sd)
    set project-scale "small"
  ]
  [   ; for LA or commercial projects
    ; first search for any large demand agents nearby
    let demand-anchors (patches in-radius search-radius with ([ bigdemand-density > 0 ]))
    ; if there are some:
    ifelse (count demand-anchors > 0) [
      ;check the size of anchors and set project-scale accordingly
      set project-scale "big"
      ; set the planned-size for projects appropriately
      let anchor-size (sum [big-demand] of demand-anchors)
      if (project-type = "commercial") [
        set planned-size ((random-normal commercial-size-mean commercial-size-sd) + anchor-size)
      ]
      if (project-type = "LA") [
        set planned-size ((random-normal LA-size-mean LA-size-sd) + anchor-size)
      ]
    ]
    [    ;if there are none
      set project-scale "small"
      ; set the planned-size for projects appropriately
      if (project-type = "commercial") [
        set planned-size (random-normal commercial-size-mean commercial-size-sd)
      ]
      if (project-type = "LA") [
        set planned-size (random-normal LA-size-mean LA-size-sd)
      ]
    ]


  ]

  set initialised TRUE
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; PHASE 2: FEASIBILITY
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to do-feasibility-study
  ;feasibility financing
  let feasibility-finance 0
  ;select appropriate feasibility finance rate, representing the likelihood of getting financing.
  if (project-type = "LA") [ set feasibility-finance (feasibility-finance-LA * LA-strategy) ]
  if (project-type = "commercial") [ set feasibility-finance (feasibility-finance-commercial * LA-strategy) ]
  if (project-type = "community") [ set feasibility-finance (feasibility-finance-community * LA-strategy) ]
  if ((random-float 1) > feasibility-finance) [
    if (project-type = "community") [
      ask owner [die]
    ]
    die
    stop
  ]
  ; increment counters for recording and display
  set feas-fin-counter (feas-fin-counter + 1)
  if (project-type = "LA") [ set LA-feas-fin-counter (LA-feas-fin-counter + 1) ]
  if (project-type = "commercial") [ set commercial-feas-fin-counter (commercial-feas-fin-counter + 1) ]
  if (project-type = "community") [ set community-feas-fin-counter (community-feas-fin-counter + 1) ]

  ; Check and calculate ECO feasibility adjustment
  let my-social-feasible-density social-feasible-density
  let my-comm-feasible-density comm-feasible-density
  let search-patches (patches in-radius search-radius with [ eco > 0 ])
  let eco-fraction 0
  if (count search-patches) > 0 [
    set eco-fraction ( sum [ eco ] of search-patches) / (count search-patches)
  ]
  if ((random-float 1) < eco-fraction) [
    ; adjust the social and economic feasibility criteria to account for ECO funding
    set my-social-feasible-density (eco-adjustment * social-feasible-density)
    set my-comm-feasible-density (eco-adjustment * comm-feasible-density)
    set eco-project True
  ]

  ; Check economic feasibility at social rates and commercial rates
  set economic-social-feasibility check-economic-feasibility my-social-feasible-density
  set economic-comm-feasibility check-economic-feasibility my-comm-feasible-density

  ; Check social feasibility (based on fuel poverty)
  set social-feasibility check-social-feasibility

  ; Check combined feasibility
  if (project-type = "LA") [
    if (economic-comm-feasibility = True) [
      set feasibility True
      set LA-comm-feasible-count (LA-comm-feasible-count + 1)
      set econ-feas-counter (econ-feas-counter + 1)
    ]
    if ((economic-social-feasibility = True) and (social-feasibility = True)) [
      set feasibility True
      set LA-soc-feasible-count (LA-soc-feasible-count + 1)
      set social-feas-counter (social-feas-counter + 1)
      set poverty-project True
    ]
    if (feasibility = True) [set LA-feasibility-counter (LA-feasibility-counter + 1)]
  ]
  if (project-type = "commercial") [
    if (economic-comm-feasibility = True) [
      set feasibility True
      set comm-feasible-count (comm-feasible-count + 1)
      set econ-feas-counter (econ-feas-counter + 1)
      set Commercial-feasibility-counter (Commercial-feasibility-counter + 1)
    ]
  ]
  if (project-type = "community") [
    if (economic-comm-feasibility = True) [
      set feasibility True
      set comm-comm-feasible-count (comm-comm-feasible-count + 1)
      set econ-feas-counter (econ-feas-counter + 1)
    ]
    if ((economic-social-feasibility = True) and (social-feasibility = True)) [
      set feasibility True
      set comm-soc-feasible-count (comm-soc-feasible-count + 1)
      set social-feas-counter (social-feas-counter + 1)
      set poverty-project True
    ]
    if (feasibility = True) [set Community-feasibility-counter (Community-feasibility-counter + 1)]
  ]

  ; kill the project and community parent
  if (not feasibility) [
    if (project-type = "community") [
      ask owner [die]
    ]
    die
    stop
  ]

  set feasibility-counter (feasibility-counter + 1)

  set busy 2 ;six months
end

to-report check-economic-feasibility [ feasible-density ]
  ;economic feasibility - check for appropriate demand density and scale
  let economic-feasibility FALSE
  if (project-scale = "small") [
    ;first collect patches with enough demand density in the search-radius
    let potential-patches (patches in-radius search-radius with [((social-demand + private-demand + commercial-demand + public-demand) / patch-area) > feasible-density])
    ; check if there is sufficient scale for a project
    if ((sum [private-demand + social-demand + public-demand + commercial-demand] of potential-patches) > planned-size) [
      set economic-feasibility TRUE
    ]
  ]
  if (project-scale = "big") [
    ;first collect patches with enough demand density in the search-radius
    let potential-patches (patches in-radius search-radius with [((social-demand + private-demand + commercial-demand + public-demand + big-demand) / patch-area) > feasible-density])
    ; check if there is sufficient scale for a project
    if ((sum [private-demand + social-demand + public-demand + commercial-demand + big-demand] of potential-patches) > planned-size) [
      set economic-feasibility TRUE
    ]
  ]
  report economic-feasibility
end

to-report check-social-feasibility
  ;social feasibility - check for proportion of fuel poverty in potential patches
  ;only relevant where social-feasibility is required, i.e. social-feasible-density
  if (project-scale = "small") [
    ; first collect patches with enough demand density in the search-radius
    let potential-patches (patches in-radius search-radius with [((social-demand + private-demand + commercial-demand + public-demand) / patch-area) > social-feasible-density])
    if (count potential-patches > 0)[
      ; check if fuel-poverty is above threshold
      let fuel-pov sum [fuel-pov-density] of potential-patches
      if (fuel-pov / (sum [private-house-density + social-house-density + public-density + commercial-density] of potential-patches) > fuel-pov-threshold) [
        set social-feasibility TRUE
      ]
    ]
  ]
  if (project-scale = "big") [
    ; first collect patches with enough demand density in the search-radius
    let potential-patches (patches in-radius search-radius with [((social-demand + private-demand + commercial-demand + public-demand + big-demand) / patch-area) > social-feasible-density])
    if (count potential-patches > 0)[
      ; check if there is sufficient scale for a project
      let fuel-pov sum [fuel-pov-density] of potential-patches
      if (fuel-pov / (sum [private-house-density + social-house-density + public-density + commercial-density + bigdemand-density] of potential-patches) > fuel-pov-threshold) [
        set social-feasibility TRUE
      ]
    ]
  ]
  report social-feasibility
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; PHASE 3: PROCURE & BUILD
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to procure-and-build
  let stopped 0
  ;get capital finance
  let capital-finance 0

  ;count number of built projects
  let my-built-projects (count projects with ([(owner = myself) and (built = True)]))

  ;calculate appropriate capital finance rate, representing the likelihood of getting financed.
  ;learning from previous projects contributes via a Weibull distribution.
  if (project-type = "LA") [
    set capital-finance (Experience1 my-built-projects (capital-finance-LA / 2.0) capital-finance-LA)
  ]
  if (project-type = "commercial") [
    set capital-finance (Experience1 my-built-projects (capital-finance-commercial / 2.0) capital-finance-commercial)
  ]
  if (project-type = "community") [
    set capital-finance (capital-finance-community)
  ]

  if ((random-float 1) > capital-finance) [
    if (project-type = "community") [
      ask owner [die]
    ]
    die
    set stopped 1
    stop
  ]
  ; increment counters
  set capital-counter (capital-counter + 1)
  if (project-type = "LA") [
    set LA-capital-counter (LA-capital-counter + 1)
  ]
  if (project-type = "commercial") [
    set commercial-capital-counter (commercial-capital-counter + 1)
  ]
  if (project-type = "community") [
    set community-capital-counter (community-capital-counter + 1)
  ]

  ;procurement contracts for network
  let procurement-success 0
  ;select appropriate procurement success rate.
  ;learning from previous projects contributes via a learning curve.
  if (project-type = "LA") [
    set procurement-success (Experience1 my-built-projects (procurement-success-LA / 2.0) procurement-success-LA)
  ]
  if (project-type = "commercial") [
    set procurement-success (Experience1 my-built-projects (procurement-success-commercial / 2.0) procurement-success-commercial)
  ]
  if (project-type = "community") [
    set procurement-success (procurement-success-community)
  ]

  if ((random-float 1) > procurement-success) [
    if (project-type = "community") [
      ask owner [die]
    ]
    die
    set stopped 1
    stop
  ]
  set procurement-counter (procurement-counter + 1)
  if (project-type = "LA") [
    set LA-procurement-counter (LA-procurement-counter + 1)
  ]
  if (project-type = "commercial") [
    set commercial-procurement-counter (commercial-procurement-counter + 1)
  ]
  if (project-type = "community") [
    set community-procurement-counter (community-procurement-counter + 1)
  ]

  ;complete contract negotiations
  let contract-success 0
  ;select appropriate contract success rate.
  ;learning from previous projects contributes via a learning curve.
  if (project-type = "LA") [
    set contract-success (Experience1 my-built-projects (contract-success-LA / 2.0) contract-success-LA)
  ]
  if (project-type = "commercial") [
    set contract-success (Experience1 my-built-projects (contract-success-commercial / 2.0) contract-success-commercial)
  ]
  if (project-type = "community") [
    set contract-success (contract-success-community)
  ]

  if ((random-float 1) > contract-success) [
    if (project-type = "community") [
      ask owner [die]
    ]
    die
    set stopped 1
    stop
  ]
  set contract-counter (contract-counter + 1)
  if (project-type = "LA") [
    set LA-contract-counter (LA-contract-counter + 1)
  ]
  if (project-type = "commercial") [
    set commercial-contract-counter (commercial-contract-counter + 1)
  ]
  if (project-type = "community") [
    set community-contract-counter (community-contract-counter + 1)
  ]

  ; Call the Build subroutine
  build-project

end

to build-project
  set built TRUE
  set size 2

  set busy 12 ;three years

  ;create counter for remaining demand required
  let required-demand planned-size
  ;sign up all the big demand anchors
  let demand-anchors (patches in-radius search-radius with ([ bigdemand-density > 0 ]))
  let my-first-patches (patches in-radius search-radius)
  let my-second-patches (patches in-radius search-radius)
  ; if it's a big project
  if (project-scale = "big") [
    ;check that these are still available - kill if they're not!
    if (count demand-anchors = 0) [
      ;set build-fails (build-fails + 1)
      if (project-type = "community") [
        ask owner [die]
      ]
      die
      stop
    ]

    ;add the demand to my project
    set my-big-demand (my-big-demand + big-demand)
    set required-demand (required-demand - my-big-demand)
    ask demand-anchors [
      ;remove big demand from patch
      set bigdemand-density 0
      set big-demand 0
    ]
  ]

  let project-scope "None"
  ; Sign up a fraction of commercial, public, private and/or social demand to achieve planned-size
  if (required-demand > 0) [
    ; set the feasible density
    let feasible-density 0
    if economic-social-feasibility [ set feasible-density social-feasible-density ]
    if economic-comm-feasibility [ set feasible-density comm-feasible-density ]

    ; Community
    if (project-type = "community") [
      ; first look for private and social housing, then public and commercial
      set my-first-patches (patches in-radius search-radius with ([ (private-demand + social-demand) > feasible-density ] ))
      set my-second-patches (patches in-radius search-radius with ([ (public-demand + social-demand + private-demand + commercial-demand) > feasible-density ] ))

      ; check if there is enough first-demand
      ifelse ( (sum [private-demand + social-demand] of my-first-patches) >= required-demand ) [
        ; set project-scope to first
        set project-scope "first"
      ]
      ; check if there is enough second-demand
      [
        ifelse ( (sum [private-demand + social-demand + public-demand + commercial-demand] of my-first-patches) >= required-demand ) [
          set project-scope "second"
        ]
        [
          set race-loss-counter (race-loss-counter + 1)
          ; kill it
          ;set build-fails (build-fails + 1)
          if (project-type = "community") [
            ask owner [die]
          ]
          die
          stop
        ]
      ]

      ; sign-up demands
      if ( project-scope = "first" ) [
        ;sign up only private + social demand
        ; if there is enough just social demand
        ifelse ((sum [social-demand] of my-first-patches) > required-demand) [
          ; all is provided by social demand
          set my-social-demand required-demand
          ask my-first-patches [
            ; if there is enough demand on this patch
            ifelse (social-demand > required-demand) [
              ; suply all required demand
              set social-demand (social-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - social-demand)
              ; and take what there is
              set social-demand 0
            ]
          ]
        ][ ;if there is not enough social-demand
          set my-social-demand (sum [social-demand] of my-first-patches)
          ; first take allthe social demand
          ask my-first-patches [
            set social-demand 0
            set required-demand (required-demand - social-demand)
          ]
          ;then take all private demand
          ask my-first-patches [
            ifelse (private-demand > required-demand) [
              ; supply all required demand
              set private-demand (private-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - private-demand)
              ; and take what there is
              set private-demand 0
            ]
          ]
        ]
      ]
      if ( project-scope = "second" ) [
        ; we already know there isn't enough social + private demand
        set my-social-demand (sum [social-demand] of my-second-patches)
        set my-private-demand (sum [private-demand] of my-second-patches)
        ; first take allthe social demand
        ask my-second-patches [
          set required-demand (required-demand - social-demand - private-demand)
          set social-demand 0
          set private-demand 0
        ]
        ifelse ((sum [public-demand] of my-second-patches) > required-demand) [
          ; all is provided by public demand
          set my-public-demand required-demand
          ask my-second-patches [
            ; if there is enough demand on this patch
            ifelse (public-demand > required-demand) [
              ; suply all required demand
              set public-demand (public-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - public-demand)
              ; and take what there is
              set public-demand 0
            ]
          ]
        ][ ;if there is not enough public-demand
          set my-public-demand (sum [public-demand] of my-second-patches)
          ; first take allthe public demand
          ask my-second-patches [
            set public-demand 0
            set required-demand (required-demand - public-demand)
          ]
          ;then take all commercial demand
          ask my-second-patches [
            ifelse (commercial-demand > required-demand) [
              ; supply all required demand
              set commercial-demand (commercial-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - commercial-demand)
              ; and take what there is
              set commercial-demand 0
            ]
          ]
        ]
      ]
    ]

    ; Commercial
    if (project-type = "commercial") [
      ; first look for private and commercial housing, then public and social
      set my-first-patches (patches in-radius search-radius with ([ (private-demand + commercial-demand) > feasible-density ] ))
      set my-second-patches (patches in-radius search-radius with ([ (public-demand + social-demand + private-demand + commercial-demand) > feasible-density ] ))

      ; check if there is enough first-demand
      ifelse ( (sum [private-demand + commercial-demand] of my-first-patches) >= required-demand ) [
        ; set project-scope to first
        set project-scope "first"
      ]
      ; check if there is enough second-demand
      [
        ifelse ( (sum [private-demand + commercial-demand + public-demand + social-demand] of my-first-patches) >= required-demand ) [
          set project-scope "second"
        ]
        [
          ; kill it
          ;set build-fails (build-fails + 1)
          if (project-type = "community") [
            ask owner [die]
          ]
          die
          stop
        ]
      ]

      ; sign-up demands
      if ( project-scope = "first" ) [
        ;sign up only private + commercial demand
        ; if there is enough just commercial demand
        ifelse ((sum [commercial-demand] of my-first-patches) > required-demand) [
          ; all is provided by commercial demand
          set my-commercial-demand required-demand
          ask my-first-patches [
            ; if there is enough demand on this patch
            ifelse (commercial-demand > required-demand) [
              ; suply all required demand
              set commercial-demand (commercial-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - commercial-demand)
              ; and take what there is
              set commercial-demand 0
            ]
          ]
        ][ ;if there is not enough commercial-demand
          set my-commercial-demand (sum [commercial-demand] of my-first-patches)
          ; first take allthe commercial demand
          ask my-first-patches [
            set commercial-demand 0
            set required-demand (required-demand - commercial-demand)
          ]
          ;then take all private demand
          ask my-first-patches [
            ifelse (private-demand > required-demand) [
              ; supply all required demand
              set private-demand (private-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - private-demand)
              ; and take what there is
              set private-demand 0
            ]
          ]
        ]
      ]
      if ( project-scope = "second" ) [
        ; we already know there isn't enough commercial + private demand
        set my-commercial-demand (sum [commercial-demand] of my-second-patches)
        set my-private-demand (sum [private-demand] of my-second-patches)
        ; first take allthe commercial demand
        ask my-second-patches [
          set required-demand (required-demand - commercial-demand - private-demand)
          set commercial-demand 0
          set private-demand 0
        ]
        ifelse ((sum [public-demand] of my-second-patches) > required-demand) [
          ; all is provided by public demand
          set my-public-demand required-demand
          ask my-second-patches [
            ; if there is enough demand on this patch
            ifelse (public-demand > required-demand) [
              ; suply all required demand
              set public-demand (public-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - public-demand)
              ; and take what there is
              set public-demand 0
            ]
          ]
        ][ ;if there is not enough public-demand
          set my-public-demand (sum [public-demand] of my-second-patches)
          ; first take allthe public demand
          ask my-second-patches [
            set public-demand 0
            set required-demand (required-demand - public-demand)
          ]
          ;then take all social demand
          ask my-second-patches [
            ifelse (social-demand > required-demand) [
              ; supply all required demand
              set social-demand (social-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - social-demand)
              ; and take what there is
              set social-demand 0
            ]
          ]
        ]
      ]
    ]

    ; LA
    if (project-type = "LA") [
      ; first look for public and social, then commercial and private
      set my-first-patches (patches in-radius search-radius with ([ (public-demand + social-demand) > feasible-density ] ))
      set my-second-patches (patches in-radius search-radius with ([ (public-demand + social-demand + private-demand + commercial-demand) > feasible-density ] ))

      ; check if there is enough first-demand
      ifelse ( (sum [public-demand + social-demand] of my-first-patches) >= required-demand ) [
        ; set project-scope to first
        set project-scope "first"
      ]
      ; check if there is enough second-demand
      [
        ifelse ( (sum [public-demand + social-demand + private-demand + commercial-demand] of my-first-patches) >= required-demand ) [
          set project-scope "second"
        ]
        [
          ; kill it
          ;set build-fails (build-fails + 1)
          if (project-type = "community") [
            ask owner [die]
          ]
          die
          stop
        ]
      ]

      ; sign-up demands
      if ( project-scope = "first" ) [
        ;sign up only public + social demand
        ; if there is enough just social demand
        ifelse ((sum [social-demand] of my-first-patches) > required-demand) [
          ; all is provided by social demand
          set my-social-demand required-demand
          ask my-first-patches [
            ; if there is enough demand on this patch
            ifelse (social-demand > required-demand) [
              ; suply all required demand
              set social-demand (social-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - social-demand)
              ; and take what there is
              set social-demand 0
            ]
          ]
        ][ ;if there is not enough social-demand
          set my-social-demand (sum [social-demand] of my-first-patches)
          ; first take allthe social demand
          ask my-first-patches [
            set social-demand 0
            set required-demand (required-demand - social-demand)
          ]
          ;then take all public demand
          ask my-first-patches [
            ifelse (public-demand > required-demand) [
              ; supply all required demand
              set public-demand (public-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - public-demand)
              ; and take what there is
              set public-demand 0
            ]
          ]
        ]
      ]
      if ( project-scope = "second" ) [
        ; we already know there isn't enough social + public demand
        set my-social-demand (sum [social-demand] of my-second-patches)
        set my-public-demand (sum [public-demand] of my-second-patches)
        ; first take allthe social demand
        ask my-second-patches [
          set required-demand (required-demand - social-demand - public-demand)
          set social-demand 0
          set public-demand 0
        ]
        ifelse ((sum [private-demand] of my-second-patches) > required-demand) [
          ; all is provided by private demand
          set my-public-demand required-demand
          ask my-second-patches [
            ; if there is enough demand on this patch
            ifelse (private-demand > required-demand) [
              ; suply all required demand
              set private-demand (private-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - private-demand)
              ; and take what there is
              set private-demand 0
            ]
          ]
        ][ ;if there is not enough private-demand
          set my-private-demand (sum [private-demand] of my-second-patches)
          ; first take allthe private demand
          ask my-second-patches [
            set private-demand 0
            set required-demand (required-demand - private-demand)
          ]
          ;then take all commercial demand
          ask my-second-patches [
            ifelse (commercial-demand > required-demand) [
              ; supply all required demand
              set commercial-demand (commercial-demand - required-demand)
              set required-demand 0
            ][ ; if there isn't enough
              ; reduce the remaining required demand
              set required-demand (required-demand - commercial-demand)
              ; and take what there is
              set commercial-demand 0
            ]
          ]
        ]
      ]
    ]
  ]

  set build-counter (build-counter + 1)
  if (project-type = "LA") [set LA-build-counter (LA-build-counter + 1)]
  if (project-type = "commercial") [set Commercial-build-counter (Commercial-build-counter + 1)]
  if (project-type = "community") [set Community-build-counter (Community-build-counter + 1)]
  ;ask owner [ set owned-projects (owned-projects + 1) ]

end


to-report Experience1 [number initial final]
  ; returns the capability factor based on a single-factor experience curve with learning rate LR.
  ; number is the number of successful projects and initial is the initial scaling factor of the capability
  set number (number + 1)
  let LR 0.2
  let elast log (1.0 - LR) 2
  report final * (1.0 - ((1 - initial) * (number ^ elast)))
end

to-report Experience2 [number1 number2 initial final]
  ; returns the capability factor based on a two-factor experience curve with learning rates LR1 and LR2.
  ; number1 & 2 the number of successful projects relevant to the two factors
  ; and initial is the initial scaling factor of the capability
  set number1 (number1 + 1)
  set number2 (number2 + 1)
  let LR1 0.15
  let LR2 0.05
  let elast1 log (1.0 - LR1) 2
  let elast2 log (1.0 - LR2) 2
  report final * (1.0 - ((1 - initial) * (number1 ^ elast1) * (number2 ^ elast2)) )
end
@#$#@#$#@
GRAPHICS-WINDOW
569
25
1107
584
-1
-1
8.0
1
10
1
1
1
0
0
0
1
0
65
0
65
0
0
1
ticks
30.0

BUTTON
463
97
529
130
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
355
605
418
638
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
60
692
333
867
Completed Projects
Time
No. of Networks
0.0
160.0
0.0
10.0
true
true
"" ""
PENS
"Total" 1.0 0 -16777216 true "" "plot count projects with [built = True]"
"LA" 1.0 0 -5825686 true "" "plot count projects with [project-type = \"LA\" and built = True]"
"Commercial" 1.0 0 -13345367 true "" "plot count projects with [project-type = \"commercial\" and built = True]"
"Community" 1.0 0 -10899396 true "" "plot count projects with [project-type = \"community\" and built = True]"

SLIDER
108
428
230
461
feasibility-finance-LA
feasibility-finance-LA
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
108
389
230
422
idea-rate-LA
idea-rate-LA
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
108
468
230
501
capital-finance-LA
capital-finance-LA
0
1
0.8
0.05
1
NIL
HORIZONTAL

SLIDER
108
508
230
541
procurement-success-LA
procurement-success-LA
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
108
548
230
581
contract-success-LA
contract-success-LA
0
1
0.7
0.05
1
NIL
HORIZONTAL

CHOOSER
142
44
280
89
city
city
"City_1"
0

TEXTBOX
163
369
276
387
LA
12
125.0
1

TEXTBOX
439
369
507
387
Community
12
55.0
1

SLIDER
258
388
381
421
idea-rate-commercial
idea-rate-commercial
0
1
1
0.05
1
NIL
HORIZONTAL

SLIDER
410
388
533
421
idea-rate-community
idea-rate-community
0
1
0.5
0.05
1
NIL
HORIZONTAL

TEXTBOX
287
369
360
399
Commercial
12
105.0
1

SLIDER
259
428
381
461
feasibility-finance-commercial
feasibility-finance-commercial
0
1
1
0.05
1
NIL
HORIZONTAL

SLIDER
410
428
533
461
feasibility-finance-community
feasibility-finance-community
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
259
468
382
501
capital-finance-commercial
capital-finance-commercial
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
410
468
533
501
capital-finance-community
capital-finance-community
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
259
508
383
541
procurement-success-commercial
procurement-success-commercial
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
410
508
534
541
procurement-success-community
procurement-success-community
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
259
549
383
582
contract-success-commercial
contract-success-commercial
0
1
0.7
0.05
1
NIL
HORIZONTAL

SLIDER
410
550
534
583
contract-success-community
contract-success-community
0
1
0.7
0.05
1
NIL
HORIZONTAL

SLIDER
1669
28
1790
61
commercial-fraction
commercial-fraction
0
1
0.05
0.05
1
NIL
HORIZONTAL

SLIDER
1808
27
1941
60
community-fraction
community-fraction
0
1
0.1
0.05
1
NIL
HORIZONTAL

MONITOR
1823
61
1916
106
communities
count instigators with [instigator-type = \"community\"]
0
1
11

MONITOR
1682
64
1767
109
commercial
count instigators with [instigator-type = \"commercial\"]
0
1
11

MONITOR
512
867
605
912
Built Projects
count projects with [Built = True]
17
1
11

CHOOSER
263
177
403
222
LA-type
LA-type
"Energy Leader" "Running Hard" "Starting Blocks" "Yet to Join"
2

SLIDER
262
269
434
302
LA-strategy
LA-strategy
0
1
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
1417
29
1646
62
comm-feasible-density
comm-feasible-density
0
2000000
260000
10000
1
NIL
HORIZONTAL

SLIDER
1417
72
1644
105
social-feasible-density
social-feasible-density
0
2000000
230000
10000
1
NIL
HORIZONTAL

PLOT
48
928
342
1078
LA
Time
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Ideas" 1.0 1 -2674135 true "" "plot LA-idea-counter"
"Feas. Finance" 1.0 1 -2064490 true "" "plot LA-feas-fin-counter"
"Feasibility" 1.0 1 -5825686 true "" "plot LA-feasibility-counter"
"Cap. Finance" 1.0 1 -13345367 true "" "plot LA-capital-counter"
"Procurement" 1.0 1 -11221820 true "" "plot LA-procurement-counter"
"Contracts" 1.0 1 -10899396 true "" "plot LA-contract-counter"

PLOT
372
927
666
1077
Commercial
Time
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Ideas" 1.0 1 -2674135 true "" "plot commercial-idea-counter"
"Feas. Finance" 1.0 1 -2064490 true "" "plot commercial-feas-fin-counter"
"Feasibility" 1.0 1 -5825686 true "" "plot Commercial-feasibility-counter"
"Cap. Finance" 1.0 1 -13345367 true "" "plot commercial-capital-counter"
"Procurement" 1.0 1 -11221820 true "" "plot commercial-procurement-counter"
"Conracts" 1.0 1 -10899396 true "" "plot commercial-contract-counter"

PLOT
696
927
990
1077
Community
Time
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Ideas" 1.0 1 -2674135 true "" "plot community-idea-counter"
"Feas. Finance" 1.0 1 -2064490 true "" "plot community-feas-fin-counter"
"Feasibility" 1.0 1 -5825686 true "" "plot Community-feasibility-counter"
"Cap. Finance" 1.0 1 -13345367 true "" "plot community-capital-counter"
"Procurement" 1.0 1 -11221820 true "" "plot community-procurement-counter"
"Contracts" 1.0 1 -10899396 true "" "plot community-contract-counter"

PLOT
349
692
640
867
Project Phases
Time
NIL
0.0
160.0
0.0
10.0
true
true
"" ""
PENS
"Ideas" 1.0 1 -2674135 true "" "plot idea-counter"
"Feas. Finance" 1.0 1 -2064490 true "" "plot feas-fin-counter"
"Feas." 1.0 1 -5825686 true "" "plot feasibility-counter"
"Cap. Finance" 1.0 1 -13345367 true "" "plot capital-counter"
"Procurement" 1.0 1 -11221820 true "" "plot procurement-counter"
"Contracts" 1.0 1 -14835848 true "" "plot contract-counter"

TEXTBOX
33
398
87
416
Idea Rate\n
11
0.0
1

TEXTBOX
32
431
91
459
Feasibility\nFinance
11
0.0
1

TEXTBOX
32
471
93
499
Capital \nFinance
11
0.0
1

TEXTBOX
32
518
104
536
Procurement
11
0.0
1

TEXTBOX
33
556
100
574
Contracts
11
0.0
1

TEXTBOX
33
341
183
371
Capabilities
24
0.0
1

TEXTBOX
26
10
176
40
Controls
24
0.0
1

TEXTBOX
32
646
271
680
Project Overview
24
0.0
1

TEXTBOX
30
883
266
919
Phases by Instigator
24
0.0
1

BUTTON
141
138
295
171
Baseline Parameters
reset-to-baseline
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
141
97
245
130
Load Map
reload-map
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
242
605
334
638
Clear Run
clear-run
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
263
229
386
262
Set LA
set-attributes
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
229
1077
341
1122
LA Built Projects
count projects with [(project-type = \"LA\") and (built = True)]
17
1
11

MONITOR
496
1077
666
1122
Commercial Built Projects
count projects with [(project-type = \"commercial\") and (built = True)]
17
1
11

MONITOR
823
1077
990
1122
Community Built Projects
count projects with [(project-type = \"community\") and (built = True)]
17
1
11

PLOT
651
692
893
868
Heat Provided (fraction)
NIL
NIL
0.0
10.0
0.0
0.01
true
false
"" ""
PENS
"Total" 1.0 0 -16777216 true "" "plot (sum [planned-size] of projects with [built = true]) / (sum [all-heat-demand] of patches)"
"LA" 1.0 0 -5825686 true "" "plot (sum [planned-size] of projects with [built = true and project-type = \"LA\"]) / (sum [all-heat-demand] of patches)"
"Commercial" 1.0 0 -13345367 true "" "plot (sum [planned-size] of projects with [built = true and project-type = \"commercial\"]) / (sum [all-heat-demand] of patches)"
"Community" 1.0 0 -10899396 true "" "plot (sum [planned-size] of projects with [built = true and project-type = \"community\"]) / (sum [all-heat-demand] of patches)"

PLOT
936
692
1176
868
Project Size
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range 0 100000000\n;set-plot-y-range 0 1000000\nset-histogram-num-bars 25" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [planned-size] of projects with [built = true]"

SLIDER
1418
212
1598
245
LA-max-operational
LA-max-operational
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
1418
256
1598
289
commercial-max-operational
commercial-max-operational
0
100
10
1
1
NIL
HORIZONTAL

SLIDER
1625
213
1821
246
LA-max-developments
LA-max-developments
0
50
10
1
1
NIL
HORIZONTAL

SLIDER
1625
256
1821
289
commercial-max-developments
commercial-max-developments
0
10
5
1
1
NIL
HORIZONTAL

TEXTBOX
36
60
116
78
1. Select City:
12
0.0
1

TEXTBOX
38
104
121
122
2. Load Map:\n
12
0.0
1

TEXTBOX
37
139
135
169
3. Set Baseline \n    Parameters:
12
0.0
1

TEXTBOX
37
191
242
221
4. (optional)    a. Select LA-type:
12
0.0
1

TEXTBOX
123
276
273
294
c. Adjust LA Strategy:
12
0.0
1

TEXTBOX
124
231
274
259
b. Apply LA-type\n    attributes:
11
0.0
1

TEXTBOX
36
317
353
347
5. (optional) Manually adjust instigator attributes:
12
0.0
1

TEXTBOX
33
611
223
641
6. Clear previous run and Go:
12
0.0
1

TEXTBOX
357
104
464
122
1+2+3 (City_1):\n
12
0.0
1

BUTTON
439
604
502
637
Step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
526
604
583
649
ticks
ticks
17
1
11

@#$#@#$#@
## WHAT IS IT?

This model simulates the development of district heat netwroks in UK cities by three possible insitgator types: local authorities, commercial developers or community organisations. Successful project development must undergo a series of steps the success of which is in part determined by a set of capabilities that the instigators possess to varying degrees.

Full project documentation is provided in the form of a Model Specification and the associated research and analysis are described in an accompanying journal paper. Both of these will be freely accessible once published.


## CREDITS AND REFERENCES

The development of this model and the associated research were funded by the UK Engineering and Physical Sciences Research Council (EPSRC) and UK Economic and Social Research Council under the iBuild project (Ref.: EP/K012398/1) and a EPSRC fellowship (EP/K022288/1).
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Baseline-City1" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommunityFraction" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [built = true]</metric>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.06"/>
      <value value="0.08"/>
      <value value="0.1"/>
      <value value="0.12"/>
      <value value="0.14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="max-developments learning" repetitions="100" runMetricsEveryStep="true">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>mean [max-developments] of instigators with [instigator-type = "commercial"]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="390000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="350000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Baseline-City2" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_2&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SearchRadius" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommFeasibleDensity" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="160000"/>
      <value value="260000"/>
      <value value="360000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="SocialFeasibleDensity" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="130000"/>
      <value value="230000"/>
      <value value="330000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommercialSize" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="2000000"/>
      <value value="9000000"/>
      <value value="18000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommunitySize" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="2000000"/>
      <value value="9000000"/>
      <value value="18000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="LASize" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="2000000"/>
      <value value="9000000"/>
      <value value="18000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="LACommAddressDensity" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.1"/>
      <value value="0.7"/>
      <value value="1"/>
      <value value="3"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommAddressDensity" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.1"/>
      <value value="0.35"/>
      <value value="1"/>
      <value value="3"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="FuelPoverty" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fuel-pov-threshold">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommMaxDevelopments" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="3"/>
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fuel-pov-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="LAMaxDevelopments" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-max-developments">
      <value value="5"/>
      <value value="10"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-max-operational">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fuel-pov-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MaxCapabilities" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-max-developments">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-max-operational">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-size-mean">
      <value value="9000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-social-threshold">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-threshold">
      <value value="0.35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fuel-pov-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Energy Leader&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-radius">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="BaselineDynamics" repetitions="100" runMetricsEveryStep="true">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario1-LA-Strategy" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario2A-Feasibility" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario2B-Capital" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario2C-Underwriting" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario3-Planning" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario4-Communities" repetitions="100" runMetricsEveryStep="true">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario5-Data" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario6-Procurement" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Scenario7-Regulation" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Add_Scenario1B-LA-Strategy+" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="BaselineDynamics-Phases" repetitions="100" runMetricsEveryStep="true">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>idea-counter</metric>
    <metric>feas-fin-counter</metric>
    <metric>feasibility-counter</metric>
    <metric>capital-counter</metric>
    <metric>procurement-counter</metric>
    <metric>contract-counter</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="LearningStatics" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="inter-actor-learning">
      <value value="0"/>
      <value value="0.02"/>
      <value value="0.05"/>
      <value value="0.1"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="CommercialFraction" repetitions="100" runMetricsEveryStep="false">
    <setup>clear-run</setup>
    <go>go</go>
    <metric>count projects with [built = true]</metric>
    <metric>count projects with [(project-type = "LA") and (built = true)]</metric>
    <metric>count projects with [(project-type = "community") and (built = true)]</metric>
    <metric>count projects with [(project-type = "commercial") and (built = true)]</metric>
    <enumeratedValueSet variable="community-fraction">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-fraction">
      <value value="0.03"/>
      <value value="0.04"/>
      <value value="0.05"/>
      <value value="0.06"/>
      <value value="0.07"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-developments">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="commercial-max-operational">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="comm-feasible-density">
      <value value="260000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-feasible-density">
      <value value="230000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-LA">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="idea-rate-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-commercial">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feasibility-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-LA">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capital-finance-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-LA">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-commercial">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="procurement-success-community">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-LA">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-commercial">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contract-success-community">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-strategy">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="LA-type">
      <value value="&quot;Starting Blocks&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="city">
      <value value="&quot;City_1&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
